@@ -378,7 +378,7 @@ def pipreqsnb_main(input_path):
 		run_pipreqs(temp_path, input_path+"requirements.txt")
 
 		#os.system("cat {}".format(temp_file))
-		#shutil.rmtree(temp_path)
+		shutil.rmtree(temp_path)
 	except Exception as e:
 		print(e)
 		if os.path.isfile(temp_file):
@@ -859,6 +859,7 @@ def find_full_project_name(name):
 
 def invoke_publishproject(servingprojectid, infra, auth_token, invokepublishproject=True, linux_user="app"):
 	# print(servingprojectid)
+	print(linux_user)
 	invoke_url = BASE_URL+'/api/servingproject/publishproject'
 	if not invokepublishproject:
 		invoke_url = BASE_URL+'/api/servingproject/publishprojectlambda'
